/****************************************************************/
/*                                                              */
/*      line.c   2D functions for kpl                           */
/*                                                              */
/*      This file is a part of kpl - a program for graphical    */
/*      presentation of data sets and functions.                */
/*                                                              */
/*      Copyright (C) 2006 by Ladislav Sevcovic                 */
/*      <ladislav.sevcovic@tuke.sk>                             */
/*                                                              */
/*      Released under the GPL; see file LICENSE for details.   */
/*                                                              */
/*      Use the following command to compile the C function     */
/*      and create a shared library:                            */
/*      gcc -Wall -shared -fPIC -o myfkt2.so myfkt2.c -lm       */
/*      Do this in a X terminal windows (shell).                */
/*      At the X terminal type:   nm myfkt2.so>myfkt2.def       */
/*                                                              */
/****************************************************************/

#include <math.h>

/****************************************************************/
/*      line(x, p)                                              */
/*      calculates of linear fuction                            */
/*                                                              */
/*    Returns: p[0] + p[1] * x                                  */
/****************************************************************/

double plotline(double x, const double* p)
{
return(p[0] + p[1]*x);
}

/****************************************************************/

double fitline(double x, const double* p)
{
  int i;
  double f = 0.0;

  if (x)
    for (i = 19; i >= 0; i--) {
      if (f)
        f *= x;
      if (p[i])
        f += p[i];
    }
  else
    f = p[0];
  return f;
}

