#
# nls
#
# Determine the nonlinear least-squares estimates of the nonlinear
# model parameters and return a class 'nls' object.
#
dataset <-
read.table(url("http://people.tuke.sk/ladislav.sevcovic/esf/data/keltt1rint.dat"),
header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)
x <- dataset$x; y <- dataset$y

#nls.control(maxiter=1000, tol=1e-6, minFactor=1/2048)
out.1 <- nls(y~a*exp(-x/b), start=c(a=1, b=5))
out.2 <- nls(y~a*exp(-x/b)+c*exp(-x/d), start=c(a=.4, b=2, c=.6, d=5))

par1 <- coef(out.1)
par2 <- coef(out.2)

xfit <- seq(0.1,18,0.01)
yfit1 <- par1[1] * exp(- xfit/par1[2])
yfit2 <- par2[1] * exp(- xfit/par2[2]) + par2[3] * exp(- xfit/par2[4])

par(mfrow=c(2,2))
# (1,1)
plot(x, y, pch=0)
lines(xfit, yfit1, col=2)
title("Nonlinear optimization: keltt1rint.dat")
# (1,2)
plot(x, y, pch=0, main="(c) L. Sevcovic 2007")
lines(xfit, yfit2, col=2)
# (2,1)
plot(x, residuals(out.1), main="y = a*exp(-x/b)")
abline(h=0, v="", col="blue") # line only in x-direction
# (2,2)
plot(x, residuals(out.2), main="y = a*exp(-x/b)+c*exp(-x/d)")
abline(h=0, v="", col="blue") # line only in x-direction
#
dev.print(pdf, file = "/media/hda8/kurz_rvedok/Vzory/keltt1rint.pdf",
family="Courier")
##
#rm(list=ls(all=TRUE))
#ls()
out.1
summary(out.1)
out.2
summary(out.2)
#residuals(out.1)
anova(out.1, out.2)
confint(out.2)
predict(out.2)
#lines(x, predict(out.2), col="blue")
#?nls
##
#names(box)
#box$parameters[1,1] # same as [1]
#box$parameters[2,1] # same as [3]
#box$parameters[1,2] # same as [2]
#box$parameters[2,2] # same as [4]
#box$parameters[,]
##
box1 <- summary(out.1)
box2 <- summary(out.2)
pars1 <- box1$parameters[,]
pars2 <- box2$parameters[,]
write.table(pars1,file="/media/hda8/kurz_rvedok/Vzory/keltt1rint_par1.txt")
write.table(pars2,file="/media/hda8/kurz_rvedok/Vzory/keltt1rint_par2.txt")
#write.table(pars,file="data_pars.txt")
#write.csv(par2, file = "data.csv")
##
#write.table(summary(out.2),file="t1rokelt_par.txt")
##
#write(x, file = "data.txt", ncolumns = if(is.character(x)) 1 else 14,
#append = FALSE, sep = " ")
##
#write.table(dataset, file = "data.txt", append = FALSE, quote = TRUE, sep = " ",
#eol = "\n", na = "NA", dec = ".", row.names = FALSE,
#col.names = TRUE, qmethod = c("escape", "double"))


