#
# nlm
#
# This function carries out a minimization of the function 'f' using
# a Newton-type algorithm.
#
dataset <-
read.table(url("http://people.tuke.sk/ladislav.sevcovic/esf/data/keltt1rint.dat"),
header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)
x <- dataset$x; y <- dataset$y

f1 <- function(p) sum((y - p[1]*exp(-x/p[2]))^2)
out1 <- nlm(f1, p = c(1, 5), hessian = TRUE)
xfit <- seq(0.1,18,0.01); yfit1 <- out1$estimate[1]*exp(-xfit/out1$estimate[2])
rezid1 <- y - out1$estimate[1]*exp(-x/out1$estimate[2])

f2 <- function(p) sum((y - (p[1]*exp(-x/p[2]) + p[3]*exp(-x/p[4])))^2)
out2 <- nlm(f2, p = c(.4, 1, .6, 5), hessian = TRUE)
yfit2 <- (out2$estimate[1]*exp(-xfit/out2$estimate[2]) + out2$estimate[3]*exp(-xfit/out2$estimate[4]))
rezid2 <- y - (out2$estimate[1]*exp(-x/out2$estimate[2]) + out2$estimate[3]*exp(-x/out2$estimate[4]))

err1 <- sqrt(diag(2*out1$minimum/(length(y) - 2) * solve(out1$hessian)))
out1$estimate
err1

err2 <- sqrt(diag(2*out2$minimum/(length(y) - 2) * solve(out2$hessian)))
out2$estimate
err2

par(mfrow=c(2,2))
## (1,1)
plot(x, y, pch=0, main="y = a*exp(-x/b)")
lines(xfit, yfit1, col=2)
## (1,2)
plot(x, y, pch=0, main="y = a*exp(-x/b)+c*exp(-x/d)")
lines(xfit, yfit2, col=2)
## (2,1)
plot(x, rezid1)
abline(h=0, v="", col="blue") # line only in x-direction
## (2,2)
plot(x, rezid2)
abline(h=0, v="", col="blue") # line only in x-direction
#
dev.print(pdf, file = "/home/laco/kurz_rvedok/Vzory/t1rokelt_nlm_url.pdf", family="Courier")
##
#write.table(out2$estimate,file="t1rokelt_par.txt")
##
write.csv(out2$estimate, file = "data.csv")
##
#rm(list=ls(all=TRUE))
ls()
#out.1
#summary(out.1)
#out.2
#summary(out.2)

#?nlm

#help.search("nlm")


