function linereg(t,u)
% Funkcia LINEREG(t,u) pre program Octave zobrazi regresnu
% priamku typu y=a*x a prevedie vypocet optimalneho parametra 'a'
% metodou najmensich stvorcov, kde 't' a 'u' su vektory
% s rovnakymi dlzkami. Zobrazi sa vyrovnavacia priamka datovych
% bodov (t(i),u(i)).
%
% Priklad pouzitia funkcie:
%                   clear all
%                   load g5.dat 
%                   x = g5(:,1);
%                   y = g5(:,2);
%                   linereg1(x,y)
%                   title('Metoda najmensich stvorcov')
%                   xlabel('Mechanicke napatie \sigma (Pa)')
%                   ylabel('Relativne predlzenie \epsilon (-)')
% 
% Priklad formatu suboru 'g5.dat':
%                   15.822	1.95E-04
%                   31.645	3.78E-04
%                   47.467	2.60E-04
%                   63.29	8.83E-04
%                   79.112	1.14E-03
%                   94.935	1.40E-03
%                   110.758	1.65E-03
%                   126.58	1.92E-03
%                   142.403	2.18E-03
%                   158.225	2.44E-03

t=t(:); u=u(:);
n=length(t);

% 'alfa' je zvolena hladina pravdepodobnosti (vyznamnosti) pre
% Studentovo rozdelenie. Viac sa docitate v ucebnom texte
% 'Pravdepodobnost a matematicka statistika v pocitacovom prostredi
% MATLABu', autori Gavalec, Kovacova, Ostertagova, Skrivanek,
% Vydavatelstvo ELFA, Kosice, 2001.
% alfa=.05; 
% tinv(1-(alfa/2),n-1)=2.2622
% je "95%-ny interval spolahlivosti" pre regresny koeficiet 'a'
%% 
% Vypocet optimalnej priamky datovych bodov (t(i),u(i))
fit1=[sum(t.*u)/sum(t.^2),0];
% Graficke zobrazenie
tline = [0, 1.1*max(t)-0.0*min(t)];
fit1curve = polyval(fit1,tline);
h = plot(tline,fit1curve,'b-;fitdata',t,u,'sk;expdata');
set(h,'markersize',5);
%legend('regresia','experiment',0)
a1=fit1(1);
% Standardna neistota parametra 'a' priamky y=a*x
sa=(sqrt(sum((t.*a1-u).^2)/((n-1)*sum(t.^2))));
if a1 >= 0 , sign = '  '; else, sign = ' - '; end
% Vypisanie vysledkov
scalex=(1.2*max(t)-0.2*min(t))-(1.2*min(t)-0.2*max(t));
scaley=(1.2*max(u)-0.2*min(u))-(1.2*min(u)-0.2*max(u));
text(t(1)/3,u(n),['y = ' sign num2str(abs(a1),7) '*x'],'FontSize',12);
text(t(1)/3,u(n)-scaley/10,['a = ' sign num2str(abs(a1),7) ' +/- ' num2str(sa,5)],'FontSize',12);
%%