#
# nls, nlm
#
# Determine the nonlinear least-squares estimates of the nonlinear
# model parameters and return a class 'nls' and 'nlm' objects.
#
# rm(list=ls(all=TRUE))
rm(list=ls())
#dataset <-
#read.table("/home/laco/rvedok/Vzory/R/aplimat/keltt1rint.dat", header=TRUE, sep="",
#dec=".")

dataset <- read.table(
#url("http://people.tuke.sk/ladislav.sevcovic/esf/data/keltt1rint.dat"), 
"/home/laco/rvedok/Vzory/R/aplimat/keltt1rint.dat", 
header=TRUE, sep="", dec=".")
#
x <- dataset$x; y <- dataset$y
xfit <- seq(0.1,18,0.1)
we <- 1/y # weighting
#nls.control(maxiter=1000, tol=1e-6, minFactor=1/2048)
out.1 <- nls(y~a*exp(-x/b), start=c(a=1, b=5))
out.2 <- nls(y~a*exp(-x/b)+c*exp(-x/d), start=c(a=.4, b=2, c=.6, d=5))
##
## weighted one exp nonlinear model 
fw <- function(p) sum(we*(y - p[1]*exp(-x/p[2]))^2)
out.w <- nlm(fw, p=c(1, 5), hessian = TRUE)
yfitw <- out.w$estimate[1] * exp(- xfit/out.w$estimate[2])
yestw <- out.w$estimate[1] * exp(- x/out.w$estimate[2])
p <- length(out.w$estimate[]) # No. of estimated parameters
sew <- sqrt(abs(diag(2*out.w$minimum*solve(out.w$hessian))/(length(y)-p)))
##
## weighted two exp nonlinear model 
f2w <- function(p) sum(we*(y - (p[1]*exp(-x/p[2]) + p[3]*exp(-x/p[4])))^2)
out2.w <- nlm(f2w, p=c(0.4, 2, 0.6, 5), hessian = TRUE)
yfit2w <- out2.w$estim[1] * exp(- xfit/out2.w$estim[2]) + out2.w$estim[3] *
exp(- xfit/out2.w$estim[4])
yest2w <- out2.w$estim[1] * exp(- x/out2.w$estim[2]) + out2.w$estim[3] *
exp(- x/out2.w$estim[4])
p2 <- length(out2.w$estim[]) # No. of estimated parameters
se2w <- sqrt(abs(diag(2*out2.w$minimum*solve(out2.w$hessian))/(length(y)-p2)))
#
par1 <- coef(out.1)
par2 <- coef(out.2)

yfit1 <- par1[1] * exp(- xfit/par1[2])
yfit2 <- par2[1] * exp(- xfit/par2[2]) + par2[3] * exp(- xfit/par2[4])

par(mfrow=c(3,2))
# (1,1)
plot(x, y, pch=0, xlab="x axis",ylab="y axis", main="nonlinear optimization")
lines(xfit, yfit1, col="navy")
lines(xfit, yfitw, col="red")
#title("nonlinear optimization: keltt1rint.dat")
# (1,2)
plot(x, y, pch=0, xlab="x axis",ylab="y axis", main="keltt1rint.dat")
lines(xfit, yfit2, col="navy")
lines(xfit, yfit2w, col="red")
# (2,1)
#plot(c(x,x),c(residuals(out.1), y-yestw))#, col=c("navy","red")
plot(x, y-yestw, col="red", pch=20, main="y = a*exp(-x/b)")
points(x, residuals(out.1), col="navy", pch=20)
abline(h=0, v="", col="blue") # line only in x-direction
# (2,2)
plot(x, y-yest2w, col="red", pch=20, main =" 
y = a*exp(-x/b)+c*exp(-x/d)")
points(x, residuals(out.2), col="navy", pch=20)
abline(h=0, v="", col="blue") # line only in x-direction
# (3,1)
#qqnorm(residuals(out.1)); qqline(residuals(out.1), col="blue")
qqnorm(yestw); qqline(yestw, col="blue")
# (3,2)
#qqnorm(residuals(out.2)); qqline(residuals(out.2), col="blue")
qqnorm(yest2w); qqline(yest2w, col="blue")
#
dev.print(pdf, file = "/home/laco/rvedok/Vzory/R/aplimat/aplimat-nls-nlm-we.pdf")
##
#ls()
out.1
summary(out.1)
out.2
summary(out.2)
#residuals(out.1)
anova(out.1, out.2)
confint(out.2)
predict(out.2)
#lines(x, predict(out.2), col="blue")
#?nls
##
#names(box)	# 'names()' The Names Attribute of an Object
			# Description: functions to get or set the names of an object.
#box$parameters[1,1] # same as [1]
#box$parameters[2,1] # same as [3]
#box$parameters[1,2] # same as [2]
#box$parameters[2,2] # same as [4]
#box$parameters[,]
##
box1 <- summary(out.1)
box2 <- summary(out.2)
pars1 <- box1$parameters[,] # short form box1$param[,]
# same as
# pars1 <- box1$coefficients[,] # short form box1$coef[,]
pars2 <- box2$parameters[,]
write.table(pars1,file="/home/laco/rvedok/Vzory/R/aplimat/kelt-par1.txt")
write.table(pars2,file="/home/laco/rvedok/Vzory/R/aplimat/kelt-par2.txt")
#write.table(pars,file="data_pars.txt")
#write.csv(par2, file = "data.csv")
##
#write.table(summary(out.2),file="t1rokelt_par.txt")
##
#write(x, file = "data.txt", ncolumns = if(is.character(x)) 1 else 14,
#append = FALSE, sep = " ")
##
#write.table(dataset, file = "data.txt", append = FALSE, quote = TRUE, sep = " ",
#eol = "\n", na = "NA", dec = ".", row.names = FALSE,
#col.names = TRUE, qmethod = c("escape", "double"))
##
# legend(locator(1), as.character(0:20), pch=0:20)
# legend("bottomleft","NA" ,as.character(0:20), pch=0:20)
##
# compute the Akaike information criterion
AIC(out.1,out.2)
#predict(out.1)
out2.w$estimate[]
se2w
