#
# Fitting Linear Models
# 'lm' is used to fit linear models. It can be used to carry out
# regression, single stratum analysis of variance and analysis of
# covariance (although 'aov' may provide a more convenient interface
# for these).
#
## Kupka 
expdata <- read.table("/home/spolocne/Vzory/R/linreg/kupka.dat", header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)
# plot(expdata) 
# summary(expdata)
x <- expdata$x; y <- expdata$y
##
## fitovanie linearnou funkciou
##
fitlin <- lm(y ~ 1 + x) # or lm(y ~ x) with same results
parlin <- coef(fitlin)
xfit <- seq(0,70,0.01)
yfitl <- parlin[1] + parlin[2] * xfit
##
plot(x, y, pch=22, xlab="x axis", ylab="y axis")
#plot(y ~ x) #  alternatively 
lines(xfit, yfitl, col=2)
title(" Linear optimization - kupka.dat")
legend("topleft", c("linear fit"), lty=1, col="red", title="LEGEND",bg="gray95")
dev.print(pdf, file = "/home/spolocne/Vzory/R/linreg/kupkalin.pdf", family="Times")
plot(fitted(fitlin), residuals(fitlin))
abline(h=0, v="", col="blue") # line only in x-direction
dev.print(pdf, file="/home/spolocne/Vzory/R/linreg/kupkalinr.pdf", width=5.0, height=5.0, pointsize=10)
summary(fitlin)
##
## Sum of Squares ~ Chi^2 
ChisqrL <- deviance(fitlin)
ChisqrL
##
## fitovanie polynomom druheho stupna
##
fitpoly <- lm(y ~ 1 + x + I(x^2))
parpoly <- coef(fitpoly)
yfitp <- parpoly[1] + parpoly[2]*xfit + parpoly[3]*xfit^2
# pdf(file = "/home/spolocne/Vzory/R/linreg/kupka_poly.pdf", family="Times")
plot(x, y, pch=22, xlab="x axis", ylab="y axis")
lines(xfit, yfitp, col=2)
title(" Linear optimization - kupka.dat")
legend("topleft", c("poly fit"), lty=1, col="red", title="LEGEND",bg="gray95")
# dev.off()
dev.print(pdf, file="/home/spolocne/Vzory/R/linreg/kupkapoly.pdf", family="Times")
plot(fitted(fitpoly), residuals(fitpoly)) # plot(x, residuals(fitpoly))
abline(h=0, v="", col="blue") # line only in x-direction
dev.print(pdf, file="/home/spolocne/Vzory/R/linreg/kupkapolyr.pdf", width=5.0, height=5.0, pointsize=10)
# grid(4, NA, lwd = 2) # grid only in y-direction
summary(fitpoly)
##
## Sum of Squares ~ Chi^2 
ChisqrP <- deviance(fitpoly)
ChisqrP
##
## computes a table of analysis of variance or deviance
## for one 'aov()' or several models 'anova()'
##
aov(fitlin)
aov(fitpoly) 
##
## compare two models...
## compare a submodel with an outer model
## and produce an analysis of variance table 
##
anova(fitlin,fitpoly)#,test = c("Chisq"))
##
qqnorm(residuals(fitlin))
qqnorm(fitlin$residuals)
qqline(residuals(fitlin))
##
qqnorm(residuals(fitpoly))
qqline(residuals(fitpoly))
##
## produces a QQ plot of two datasets 
qqplot(x, y, plot.it = TRUE)
##
plot(confidence.ellipse(fitlin, levels=c(0.5,0.75,0.95)), type="l")
data.ellipse(x,y, levels=c(.5,.75,.9,.95))
## 
par(mfrow=c(2,2));plot(fitlin);par(mfrow=c(1,1))
dev.print(pdf, file="/home/spolocne/Vzory/R/linreg/kupkalin4.pdf", family="Times")
##
## compute the Akaike information criterion
##
AIC(fitlin)
AIC(fitpoly)



