#
# nlm
#
# This function carries out a minimization of the functions 'f*' using
# a Newton-type algorithm.
#
# address = url("http://people.tuke.sk/ladislav.sevcovic/esf/data/bonate.dat")
# print(load(url("http://some.where.net/R/data/kprats.rda")))
# dataset <- read.table(file = url(address))
##
dataset <- read.table(url("http://people.tuke.sk/ladislav.sevcovic/esf/data/bonate.dat"), header=TRUE, sep="", na.strings="NA", dec=".", strip.white=TRUE)
##
# dataset <- read.table("/media/hda8/kurz_rvedok/Vzory/bonate.dat", header=TRUE,
# sep="", na.strings="NA", dec=".", strip.white=TRUE)
##
x <- dataset$x; y <- dataset$y
we <- 1/y # weighting 

f1 <- function(p) sum((y - p[1]*exp(-x*p[2]))^2)
out1 <- nlm(f1, p = c(.5, 1), hessian = TRUE)
xfit <- seq(0.1,96,0.01); yfit1 <- out1$estimate[1]*exp(-xfit*out1$estimate[2])
rezid1 <- y - out1$estimate[1]*exp(-x*out1$estimate[2])

f2 <- function(p) sum((y - (p[1]*exp(-x*p[2]) + p[3]*exp(-x*p[4])))^2)

f2w <- function(p) sum(we*(y - (p[1]*exp(-x*p[2]) + p[3]*exp(-x*p[4])))^2)
#out2 <- nlm(f2, p = c(.4, 1, .6, 5), hessian = TRUE)

out2 <- nlm(f2, p = c(0, 0, 1, 1), hessian = TRUE)
out2w <- nlm(f2w, p = c(0, 0, 1, 1), hessian = TRUE)

yfit2 <- (out2$estimate[1]*exp(-xfit*out2$estimate[2]) +
out2$estimate[3]*exp(-xfit*out2$estimate[4]))

yfit2w <- (out2w$estimate[1]*exp(-xfit*out2w$estimate[2]) +
out2w$estimate[3]*exp(-xfit*out2w$estimate[4]))

rezid2 <- y - (out2$estimate[1]*exp(-x*out2$estimate[2]) +
out2$estimate[3]*exp(-x*out2$estimate[4]))

rezid2w <- y - (out2w$estimate[1]*exp(-x*out2w$estimate[2]) +
out2w$estimate[3]*exp(-x*out2w$estimate[4]))


err1 <- sqrt(diag(2*out1$minimum/(length(y) - 2) * solve(out1$hessian)))
out1$estimate
err1

err2 <- sqrt(diag(2*out2$minimum/(length(y) - 4) * solve(out2$hessian)))
out2$estimate
err2

par(mfrow=c(2,2))
## (1,1)
plot(x, y, pch=0, main="y = a*exp(-x*b)+c*exp(-x*d)\n weighting method: w = 1/y")
lines(xfit, yfit2w, col=2)
## (1,2)
plot(x, y, pch=0, main="y = a*exp(-x*b)+c*exp(-x*d)\n unweighted")
lines(xfit, yfit2, col=2)
## (2,1)
plot(x, rezid2w)
abline(h=0, v="", col="blue") # line only in x-direction
## (2,2)
plot(x, rezid2)
abline(h=0, v="", col="blue") # line only in x-direction
##
dev.print(pdf, file = "/media/hda8/kurz_rvedok/Vzory/bonate_nlm.pdf",
family="Courier")
##
rm(list=ls(all=TRUE))
#ls()
out1
write.table(out2,file="bonate-par.txt")
#summary(out1)
#out2
#summary(out2)

#?nlm

#help.search("nlm")


